searchData={"items":[{"type":"module","title":"Membrane.Matroska.Demuxer","doc":"Filter element for demuxing Matroska files.\n\nReceives a bytestream in Matroska file format as input and outputs the constituent tracks of that file\nonto seperate pads.\n\nThis demuxer is only capable of demuxing tracks encoded with VP8, VP9, H264 or Opus.","ref":"Membrane.Matroska.Demuxer.html"},{"type":"module","title":"Pads - Membrane.Matroska.Demuxer","doc":"### `:input`\n\nAccepted formats:\n```\n%RemoteStream{content_format: format, type: :bytestream} when format in [nil, :WEBM, Matroska]\n```\n\nDirection: | `:input`\nAvailability: | `:always`\nFlow control: | `:manual`\nDemand unit: | `:buffers`\n\n\n### `:output`\n\nAccepted formats:\n```\n%H264{stream_structure: {:avc3, _dcr}}\n```\n```\nOpus\n```\n```\n%RemoteStream{content_format: format, type: :packetized} when format in [VP8, VP9]\n```\n\nDirection: | `:output`\nAvailability: | `:on_request`\nFlow control: | `:manual`\nDemand unit: | `nil`","ref":"Membrane.Matroska.Demuxer.html#module-pads"},{"type":"module","title":"Membrane.Matroska.Muxer","doc":"Filter element for muxing Matroska files.\n\nIt accepts an arbitrary number of Opus, VP8, VP9 or H264 streams and outputs a bytestream in Matroska format containing those streams.\n\nMuxer guidelines\nhttps://www.matroskaproject.org/docs/container/","ref":"Membrane.Matroska.Muxer.html"},{"type":"module","title":"Element options - Membrane.Matroska.Muxer","doc":"Passed via struct `t:Membrane.Matroska.Muxer.t/0`\n\n- `title`  \n\n  ```\n  String.t()\n  ```\n  \n  Default value: `\"Membrane Matroska file\"`  \n  Title to be used in the `Segment/Info/Title` element\n\n\n- `date`  \n\n  ```\n  nil | DateTime.t()\n  ```\n  \n  Default value: `nil`  \n  Datetime which will be store in  the `Segment/Info/DateUTC` element.\n                    Default value is the time of initialization of this element.","ref":"Membrane.Matroska.Muxer.html#module-element-options"},{"type":"module","title":"Pads - Membrane.Matroska.Muxer","doc":"### `:input`\n\nAccepted formats:\n```\n%H264{nalu_in_metadata?: true, stream_structure: structure} when H264.is_avc(structure)\n```\n```\n%Opus{self_delimiting?: false, channels: channels} when channels in [1, 2]\n```\n```\n%RemoteStream{content_format: format, type: :packetized} when format in [VP8, VP9]\n```\n\nDirection: | `:input`\nAvailability: | `:on_request`\nFlow control: | `:manual`\nDemand unit: | `:buffers`\n\n\n### `:output`\n\nAccepted formats:\n```\n%RemoteStream{content_format: Matroska}\n```\n\nDirection: | `:output`\nAvailability: | `:always`\nFlow control: | `:manual`\nDemand unit: | `nil`","ref":"Membrane.Matroska.Muxer.html#module-pads"},{"type":"function","title":"Membrane.Matroska.Muxer.options/0","doc":"Returns description of options available for this module","ref":"Membrane.Matroska.Muxer.html#options/0"},{"type":"type","title":"Membrane.Matroska.Muxer.t/0","doc":"Struct containing options for `Membrane.Matroska.Muxer`","ref":"Membrane.Matroska.Muxer.html#t:t/0"},{"type":"module","title":"Membrane.Matroska.Parser.EBML","doc":"Helper functions for decoding and encoding EBML elements.\n\nEBML RFC: https://datatracker.ietf.org/doc/html/rfc8794\n\nNote that this module does not support parsing Master Elements with unknown data size\nhttps://datatracker.ietf.org/doc/html/rfc8794#name-unknown-data-size","ref":"Membrane.Matroska.Parser.EBML.html"},{"type":"function","title":"Membrane.Matroska.Parser.EBML.decode_element/1","doc":"Returns an EBML element's name, type, and data","ref":"Membrane.Matroska.Parser.EBML.html#decode_element/1"},{"type":"function","title":"Membrane.Matroska.Parser.EBML.decode_element_name/1","doc":"Returns the name associated with the EBML ELEMENT_ID of the first Element in the input binary.\n\nEMBL elements are identified by the hexadecimal representation of the entire leading VINT including WIDTH, MARKER and DATA","ref":"Membrane.Matroska.Parser.EBML.html#decode_element_name/1"},{"type":"function","title":"Membrane.Matroska.Parser.EBML.decode_vint/1","doc":"Returns the number encoded in the VINT_DATA field of the first VINT in the input binary","ref":"Membrane.Matroska.Parser.EBML.html#decode_vint/1"},{"type":"function","title":"Membrane.Matroska.Parser.EBML.parse_binary/1","doc":"","ref":"Membrane.Matroska.Parser.EBML.html#parse_binary/1"},{"type":"function","title":"Membrane.Matroska.Parser.EBML.parse_date/1","doc":"","ref":"Membrane.Matroska.Parser.EBML.html#parse_date/1"},{"type":"function","title":"Membrane.Matroska.Parser.EBML.parse_float/1","doc":"","ref":"Membrane.Matroska.Parser.EBML.html#parse_float/1"},{"type":"function","title":"Membrane.Matroska.Parser.EBML.parse_integer/1","doc":"","ref":"Membrane.Matroska.Parser.EBML.html#parse_integer/1"},{"type":"function","title":"Membrane.Matroska.Parser.EBML.parse_master/2","doc":"","ref":"Membrane.Matroska.Parser.EBML.html#parse_master/2"},{"type":"function","title":"Membrane.Matroska.Parser.EBML.parse_string/1","doc":"","ref":"Membrane.Matroska.Parser.EBML.html#parse_string/1"},{"type":"function","title":"Membrane.Matroska.Parser.EBML.parse_uint/1","doc":"","ref":"Membrane.Matroska.Parser.EBML.html#parse_uint/1"},{"type":"function","title":"Membrane.Matroska.Parser.EBML.parse_utf8/1","doc":"","ref":"Membrane.Matroska.Parser.EBML.html#parse_utf8/1"},{"type":"type","title":"Membrane.Matroska.Parser.EBML.element_type_t/0","doc":"","ref":"Membrane.Matroska.Parser.EBML.html#t:element_type_t/0"},{"type":"module","title":"Membrane.Matroska.Schema","doc":"Matroska structure schema for muxing and demuxing\n\nDocs:\n  - EBML https://datatracker.ietf.org/doc/html/rfc8794\n  - Matroska https://matroska.org/technical/basics.html\n\nMatroska elements and ID's https://www.ietf.org/archive/id/draft-ietf-cellar-matroska-10.html#name-matroska-schema\nMatroska supported Matroska elements https://www.matroskaproject.org/docs/container/#EBML","ref":"Membrane.Matroska.Schema.html"},{"type":"function","title":"Membrane.Matroska.Schema.deserialize_matroska/1","doc":"","ref":"Membrane.Matroska.Schema.html#deserialize_matroska/1"},{"type":"function","title":"Membrane.Matroska.Schema.element_id_to_name/1","doc":"","ref":"Membrane.Matroska.Schema.html#element_id_to_name/1"},{"type":"function","title":"Membrane.Matroska.Schema.element_type/1","doc":"","ref":"Membrane.Matroska.Schema.html#element_type/1"},{"type":"function","title":"Membrane.Matroska.Schema.name_to_element_id/1","doc":"","ref":"Membrane.Matroska.Schema.html#name_to_element_id/1"},{"type":"function","title":"Membrane.Matroska.Schema.serialize_matroska/1","doc":"","ref":"Membrane.Matroska.Schema.html#serialize_matroska/1"},{"type":"extras","title":"Membrane Matroska Plugin","doc":"# Membrane Matroska Plugin\n\n[![Hex.pm](https://img.shields.io/hexpm/v/membrane_matroska_plugin.svg)](https://hex.pm/packages/membrane_matroska_plugin)\n[![API Docs](https://img.shields.io/badge/api-docs-yellow.svg?style=flat)](https://hexdocs.pm/membrane_matroska_plugin)\n[![CircleCI](https://circleci.com/gh/membraneframework/membrane_matroska_plugin.svg?style=svg)](https://circleci.com/gh/membraneframework/membrane_matroska_plugin)\n\nMembrane plugin for muxing and demuxing files in the [Matroska](https://www.matroska.org/index.html) format.\n\nIt is part of [Membrane Multimedia Framework](https://membraneframework.org).\n\n- Both muxer and demuxer support tracks encoded with VP8, VP9, H264 and Opus.\n- Opus tracks with more than 2 channels are not supported.\n- Demuxing of files containing [laced](https://www.ietf.org/archive/id/draft-ietf-cellar-matroska-08.html#section-12.3) frames is not supported.\n- Passing tag values is not supported","ref":"readme.html"},{"type":"extras","title":"Installation - Membrane Matroska Plugin","doc":"The package can be installed by adding `membrane_matroska_plugin` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n\t{:membrane_matroska_plugin, \"~> 0.5.1\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Usage - Membrane Matroska Plugin","doc":"### `Membrane.Matroska.Muxer`\nMatroska muxer requires a sink that can handle `Membrane.File.SeekEvent`, e.g. `Membrane.File.Sink`.\nFor an example of muxing streams to a regular matroska file, refer to [`examples/muxer_h264.exs`](examples/muxer_h264.exs).\n\nTo run the example, you can use the following command:\n ```bash\nelixir examples/muxer_h264.exs\n``` \n\n### `Membrane.Matroska.Demuxer`\nFor an example of demuxing streams, refer to [`examples/demuxer_h264.exs`](examples/demuxer_h264.exs). \n\nTo run the example, use the following command:\n```bash\nelixir examples/demuxer_h264.exs\n```\n\nYou can expect `demuxing_output` folder to appear and contain an audio file `2.ogg` and a video file `1.h264`.","ref":"readme.html#usage"},{"type":"extras","title":"Copyright and License - Membrane Matroska Plugin","doc":"Copyright 2022, [Software Mansion](https://swmansion.com/?utm_source=git&utm_medium=readme&utm_campaign=membrane_matroska_plugin)\n\n[![Software Mansion](https://logo.swmansion.com/logo?color=white&variant=desktop&width=200&tag=membrane-github)](https://swmansion.com/?utm_source=git&utm_medium=readme&utm_campaign=membrane_matroska_plugin)\n\nLicensed under the [Apache License, Version 2.0](LICENSE)","ref":"readme.html#copyright-and-license"},{"type":"extras","title":"LICENSE","doc":"Apache License\n                           Version 2.0, January 2004\n                        http://www.apache.org/licenses/\n\n   TERMS AND CONDITIONS FOR USE, REPRODUCTION, AND DISTRIBUTION\n\n   1. Definitions.\n\n      \"License\" shall mean the terms and conditions for use, reproduction,\n      and distribution as defined by Sections 1 through 9 of this document.\n\n      \"Licensor\" shall mean the copyright owner or entity authorized by\n      the copyright owner that is granting the License.\n\n      \"Legal Entity\" shall mean the union of the acting entity and all\n      other entities that control, are controlled by, or are under common\n      control with that entity. For the purposes of this definition,\n      \"control\" means (i) the power, direct or indirect, to cause the\n      direction or management of such entity, whether by contract or\n      otherwise, or (ii) ownership of fifty percent (50%) or more of the\n      outstanding shares, or (iii) beneficial ownership of such entity.\n\n      \"You\" (or \"Your\") shall mean an individual or Legal Entity\n      exercising permissions granted by this License.\n\n      \"Source\" form shall mean the preferred form for making modifications,\n      including but not limited to software source code, documentation\n      source, and configuration files.\n\n      \"Object\" form shall mean any form resulting from mechanical\n      transformation or translation of a Source form, including but\n      not limited to compiled object code, generated documentation,\n      and conversions to other media types.\n\n      \"Work\" shall mean the work of authorship, whether in Source or\n      Object form, made available under the License, as indicated by a\n      copyright notice that is included in or attached to the work\n      (an example is provided in the Appendix below).\n\n      \"Derivative Works\" shall mean any work, whether in Source or Object\n      form, that is based on (or derived from) the Work and for which the\n      editorial revisions, annotations, elaborations, or other modifications\n      represent, as a whole, an original work of authorship. For the purposes\n      of this License, Derivative Works shall not include works that remain\n      separable from, or merely link (or bind by name) to the interfaces of,\n      the Work and Derivative Works thereof.\n\n      \"Contribution\" shall mean any work of authorship, including\n      the original version of the Work and any modifications or additions\n      to that Work or Derivative Works thereof, that is intentionally\n      submitted to Licensor for inclusion in the Work by the copyright owner\n      or by an individual or Legal Entity authorized to submit on behalf of\n      the copyright owner. For the purposes of this definition, \"submitted\"\n      means any form of electronic, verbal, or written communication sent\n      to the Licensor or its representatives, including but not limited to\n      communication on electronic mailing lists, source code control systems,\n      and issue tracking systems that are managed by, or on behalf of, the\n      Licensor for the purpose of discussing and improving the Work, but\n      excluding communication that is conspicuously marked or otherwise\n      designated in writing by the copyright owner as \"Not a Contribution.\"\n\n      \"Contributor\" shall mean Licensor and any individual or Legal Entity\n      on behalf of whom a Contribution has been received by Licensor and\n      subsequently incorporated within the Work.\n\n   2. Grant of Copyright License. Subject to the terms and conditions of\n      this License, each Contributor hereby grants to You a perpetual,\n      worldwide, non-exclusive, no-charge, royalty-free, irrevocable\n      copyright license to reproduce, prepare Derivative Works of,\n      publicly display, publicly perform, sublicense, and distribute the\n      Work and such Derivative Works in Source or Object form.\n\n   3. Grant of Patent License. Subject to the terms and conditions of\n      this License, each Contributor hereby grants to You a perpetual,\n      worldwide, non-exclusive, no-charge, royalty-free, irrevocable\n      (except as stated in this section) patent license to make, have made,\n      use, offer to sell, sell, import, and otherwise transfer the Work,\n      where such license applies only to those patent claims licensable\n      by such Contributor that are necessarily infringed by their\n      Contribution(s) alone or by combination of their Contribution(s)\n      with the Work to which such Contribution(s) was submitted. If You\n      institute patent litigation against any entity (including a\n      cross-claim or counterclaim in a lawsuit) alleging that the Work\n      or a Contribution incorporated within the Work constitutes direct\n      or contributory patent infringement, then any patent licenses\n      granted to You under this License for that Work shall terminate\n      as of the date such litigation is filed.\n\n   4. Redistribution. You may reproduce and distribute copies of the\n      Work or Derivative Works thereof in any medium, with or without\n      modifications, and in Source or Object form, provided that You\n      meet the following conditions:\n\n      (a) You must give any other recipients of the Work or\n          Derivative Works a copy of this License; and\n\n      (b) You must cause any modified files to carry prominent notices\n          stating that You changed the files; and\n\n      (c) You must retain, in the Source form of any Derivative Works\n          that You distribute, all copyright, patent, trademark, and\n          attribution notices from the Source form of the Work,\n          excluding those notices that do not pertain to any part of\n          the Derivative Works; and\n\n      (d) If the Work includes a \"NOTICE\" text file as part of its\n          distribution, then any Derivative Works that You distribute must\n          include a readable copy of the attribution notices contained\n          within such NOTICE file, excluding those notices that do not\n          pertain to any part of the Derivative Works, in at least one\n          of the following places: within a NOTICE text file distributed\n          as part of the Derivative Works; within the Source form or\n          documentation, if provided along with the Derivative Works; or,\n          within a display generated by the Derivative Works, if and\n          wherever such third-party notices normally appear. The contents\n          of the NOTICE file are for informational purposes only and\n          do not modify the License. You may add Your own attribution\n          notices within Derivative Works that You distribute, alongside\n          or as an addendum to the NOTICE text from the Work, provided\n          that such additional attribution notices cannot be construed\n          as modifying the License.\n\n      You may add Your own copyright statement to Your modifications and\n      may provide additional or different license terms and conditions\n      for use, reproduction, or distribution of Your modifications, or\n      for any such Derivative Works as a whole, provided Your use,\n      reproduction, and distribution of the Work otherwise complies with\n      the conditions stated in this License.\n\n   5. Submission of Contributions. Unless You explicitly state otherwise,\n      any Contribution intentionally submitted for inclusion in the Work\n      by You to the Licensor shall be under the terms and conditions of\n      this License, without any additional terms or conditions.\n      Notwithstanding the above, nothing herein shall supersede or modify\n      the terms of any separate license agreement you may have executed\n      with Licensor regarding such Contributions.\n\n   6. Trademarks. This License does not grant permission to use the trade\n      names, trademarks, service marks, or product names of the Licensor,\n      except as required for reasonable and customary use in describing the\n      origin of the Work and reproducing the content of the NOTICE file.\n\n   7. Disclaimer of Warranty. Unless required by applicable law or\n      agreed to in writing, Licensor provides the Work (and each\n      Contributor provides its Contributions) on an \"AS IS\" BASIS,\n      WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or\n      implied, including, without limitation, any warranties or conditions\n      of TITLE, NON-INFRINGEMENT, MERCHANTABILITY, or FITNESS FOR A\n      PARTICULAR PURPOSE. You are solely responsible for determining the\n      appropriateness of using or redistributing the Work and assume any\n      risks associated with Your exercise of permissions under this License.\n\n   8. Limitation of Liability. In no event and under no legal theory,\n      whether in tort (including negligence), contract, or otherwise,\n      unless required by applicable law (such as deliberate and grossly\n      negligent acts) or agreed to in writing, shall any Contributor be\n      liable to You for damages, including any direct, indirect, special,\n      incidental, or consequential damages of any character arising as a\n      result of this License or out of the use or inability to use the\n      Work (including but not limited to damages for loss of goodwill,\n      work stoppage, computer failure or malfunction, or any and all\n      other commercial damages or losses), even if such Contributor\n      has been advised of the possibility of such damages.\n\n   9. Accepting Warranty or Additional Liability. While redistributing\n      the Work or Derivative Works thereof, You may choose to offer,\n      and charge a fee for, acceptance of support, warranty, indemnity,\n      or other liability obligations and/or rights consistent with this\n      License. However, in accepting such obligations, You may act only\n      on Your own behalf and on Your sole responsibility, not on behalf\n      of any other Contributor, and only if You agree to indemnify,\n      defend, and hold each Contributor harmless for any liability\n      incurred by, or claims asserted against, such Contributor by reason\n      of your accepting any such warranty or additional liability.\n\n   END OF TERMS AND CONDITIONS\n\n   APPENDIX: How to apply the Apache License to your work.\n\n      To apply the Apache License to your work, attach the following\n      boilerplate notice, with the fields enclosed by brackets \"[]\"\n      replaced with your own identifying information. (Don't include\n      the brackets!)  The text should be enclosed in the appropriate\n      comment syntax for the file format. We also recommend that a\n      file or class name and description of purpose be included on the\n      same \"printed page\" as the copyright notice for easier\n      identification within third-party archives.\n\n   Copyright 2020 Software Mansion\n\n   Licensed under the Apache License, Version 2.0 (the \"License\");\n   you may not use this file except in compliance with the License.\n   You may obtain a copy of the License at\n\n       http://www.apache.org/licenses/LICENSE-2.0\n\n   Unless required by applicable law or agreed to in writing, software\n   distributed under the License is distributed on an \"AS IS\" BASIS,\n   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.\n   See the License for the specific language governing permissions and\n   limitations under the License.","ref":"license.html"}],"content_type":"text/markdown"}